@@ -15,6 +15,7 @@
 """Optax: composable gradient processing and optimization, in JAX."""
 
 from optax._src.alias import adabelief
+from optax._src.alias import adafactor
 from optax._src.alias import adagrad
 from optax._src.alias import adam
 from optax._src.alias import adamw
@@ -45,6 +46,8 @@ from optax._src.clipping import clip_by_global_norm
 from optax._src.clipping import ClipByGlobalNormState
 from optax._src.clipping import ClipState
 from optax._src.combine import chain
+from optax._src.combine import multi_transform
+from optax._src.combine import MultiTransformState
 from optax._src.constrain import keep_params_nonnegative
 from optax._src.constrain import NonNegativeParamsState
 from optax._src.constrain import zero_nans
@@ -52,6 +55,9 @@ from optax._src.constrain import ZeroNansState
 from optax._src.control_variates import control_delta_method
 from optax._src.control_variates import control_variates_jacobians
 from optax._src.control_variates import moving_avg_baseline
+from optax._src.factorized import FactoredParameterStats
+from optax._src.factorized import FactoredState
+from optax._src.factorized import scale_by_factored_rms
 from optax._src.linear_algebra import global_norm
 from optax._src.linear_algebra import matrix_inverse_pth_root
 from optax._src.linear_algebra import power_iteration
@@ -138,10 +144,11 @@ from optax._src.wrappers import MaybeUpdateState
 from optax._src.wrappers import MultiSteps
 from optax._src.wrappers import MultiStepsState
 
-__version__ = "0.0.8"
+__version__ = "0.0.9"
 
 __all__ = (
     "adabelief",
+    "adafactor",
     "adagrad",
     "adam",
     "adamw",
@@ -179,6 +186,8 @@ __all__ = (
     "EmaState",
     "EmptyState",
     "exponential_decay",
+    "FactoredState",
+    "FactoredParameterStats",
     "fisher_diag",
     "flatten",
     "fromage",
@@ -204,6 +213,8 @@ __all__ = (
     "matrix_inverse_pth_root",
     "masked",
     "MaskedState",
+    "multi_transform",
+    "MultiTransformState",
     "measure_valued_jacobians",
     "moving_avg_baseline",
     "multi_normal",
