@@ -27,7 +27,6 @@ import numpy as np
 from optax._src import base
 
 Array = jnp.ndarray
-PyTree = Any
 
 
 def flatten(
@@ -229,7 +228,6 @@ class MultiSteps:
 
   def update(self, grads: Any, state: MultiStepsState, params: Any = None):
     """Accumulates gradients and proposes non-zero updates every `k_steps`."""
-    del params
     k_steps = self._every_k_schedule(state.gradient_step)
     acc_grads = jax.tree_util.tree_multimap(lambda a, b: a + b, grads,
                                             state.acc_grads)
@@ -241,7 +239,7 @@ class MultiSteps:
       else:
         grads_for_update = acc_grads
       updates, new_inner_state = self._opt.update(
-          grads_for_update, state.inner_opt_state)
+          grads_for_update, state.inner_opt_state, params=params)
       new_state = MultiStepsState(mini_step=jnp.zeros([], dtype=jnp.int64),
                                   gradient_step=state.gradient_step + 1,
                                   inner_opt_state=new_inner_state,
@@ -250,7 +248,10 @@ class MultiSteps:
 
     def mid_step(args):
       del args
-      updates = _zeros_tree_like(grads)
+      updates_shape_dtype, _ = jax.eval_shape(
+          self._opt.update, acc_grads, state.inner_opt_state, params=params)
+      updates = jax.tree_map(lambda sd: jnp.zeros(sd.shape, sd.dtype),
+                             updates_shape_dtype)
       new_state = MultiStepsState(mini_step=state.mini_step + 1,
                                   gradient_step=state.gradient_step,
                                   inner_opt_state=state.inner_opt_state,
@@ -275,39 +276,35 @@ class MaskedState(NamedTuple):
 
 def masked(
     inner: base.GradientTransformation,
-    mask: Union[PyTree, Callable[[base.Params], PyTree]]
+    mask: Union[base.PyTree, Callable[[base.Params], base.PyTree]]
 ) -> base.GradientTransformation:
   """Mask updates so only a subset of them are computed.
 
   For example, it is common to skip weight decay for BatchNorm scale and all
   bias parameters. In many networks, these are the only parameters with only
   one dimension. So, you may create a mask function to mask these out as
-  follows:
+  follows::
 
-  ```
-  mask_fn = lambda p: jax.tree_util.tree_map(lambda x: x.ndim != 1, p)
-  custom_weight_decay = optax.masked(optax.add_decayed_weights(0.001), mask_fn)
-  ```
+    mask_fn = lambda p: jax.tree_map(lambda x: x.ndim != 1, p)
+    weight_decay = optax.masked(optax.add_decayed_weights(0.001), mask_fn)
 
-  You may alternatively create the mask pytree upfront:
+  You may alternatively create the mask pytree upfront::
 
-  ```
-  mask = jax.tree_util.tree_map(lambda x: x.ndim != 1, params)
-  custom_weight_decay = optax.masked(optax.add_decayed_weights(0.001), mask)
-  ```
+    mask = jax.tree_map(lambda x: x.ndim != 1, params)
+    weight_decay = optax.masked(optax.add_decayed_weights(0.001), mask)
 
-  For the `inner` transform, state will only be stored for the parameters that
-  have a mask value of `True`.
+  For the ``inner`` transform, state will only be stored for the parameters that
+  have a mask value of ``True``.
 
   Args:
     inner: Inner transformation to mask.
     mask: a PyTree with same structure as (or a prefix of) the params PyTree,
       or a Callable that returns such a pytree given the params/updates.
-      The leaves should be booleans, `True` for leaves/subtrees you want to
-      apply the transformation to, and `False` for those you want to skip.
+      The leaves should be booleans, ``True`` for leaves/subtrees you want to
+      apply the transformation to, and ``False`` for those you want to skip.
 
   Returns:
-    New GradientTransformation wrapping `inner`.
+    New GradientTransformation wrapping ``inner``.
   """
   def init_fn(params):
     flat_mask, treedef = tree_flatten(mask(params) if callable(mask) else mask)
@@ -322,7 +319,7 @@ def masked(
     flat_updates = treedef.flatten_up_to(updates)
     masked_updates = [g for g, m in zip(flat_updates, flat_mask) if m]
 
-    if params:
+    if params is not None:
       flat_params = treedef.flatten_up_to(params)
       masked_params = [p for p, m in zip(flat_params, flat_mask) if m]
     else:
@@ -389,4 +386,3 @@ def maybe_update(
     return updates, MaybeUpdateState(new_inner_state, state.step + 1)
 
   return base.GradientTransformation(init_fn, update_fn)
-
